@@ -215,9 +215,11 @@ class Vulnerability:
     Represents <xs:complexType name="vulnerability">
     """
 
-    def __init__(self, id: str, source_name: Optional[str], source_url: Optional[str],
-                 ratings: Optional[List[VulnerabilityRating]], cwes: Optional[List[int]], description: Optional[str],
-                 recommendations: Optional[List[str]], advisories: Optional[List[str]]) -> None:
+    def __init__(self, id: str, source_name: Optional[str] = None, source_url: Optional[str] = None,
+                 ratings: Optional[List[VulnerabilityRating]] = None,
+                 cwes: Optional[List[int]] = None, description: Optional[str] = None,
+                 recommendations: Optional[List[str]] = None,
+                 advisories: Optional[List[str]] = None) -> None:
         self._id = id
         self._source_name = source_name
         self._source_url: Optional[ParseResult] = urlparse(source_url) if source_url else None
